==> Theophrastus-1.3.14.10516.tar.gz: Theophrastus-1.3.14.10516/Theophrastus/newsletter_extension/models.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: models.py 10455 2017-11-07 09:08:16Z David $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: David $
# $Date: 2017-11-07 17:08:16 +0800 (Tue, 07 Nov 2017) $
# $Revision: 10455 $

from Theophrastus.models import Newsletter, Contact
from django.db import models
from django.utils.translation import ugettext_lazy as _

class Header(models.Model):

    content = models.TextField(
        _('Header content'), blank=True, null=True,
        help_text=_('Custom your header content.'))

    def __unicode__(self):
        return _('Header %s') % str(self.id)

    class Meta:
        verbose_name = _('Header')
        verbose_name_plural = _('Headers')

class Footer(models.Model):

    content = models.TextField(
        _('Footer content'), blank=True, null=True,
        help_text=_('Custom your footer content.'))

    def __unicode__(self):
        return _('Footer %s') % str(self.id)

    class Meta:
        verbose_name = _('Footer')
        verbose_name_plural = _('Footers')

class ErrorMessage(models.Model):

    message =  models.CharField(max_length=2048, blank=True, null=True)

    newsletter = models.ForeignKey(Newsletter, verbose_name=_('newsletter'))

    contact = models.ForeignKey(Contact, verbose_name=_('contact'))

==> Theophrastus-1.3.28.10777.tar.gz: Theophrastus-1.3.28.10777/Theophrastus/newsletter_extension/models.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: models.py 10799 2018-03-01 03:15:51Z David $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: David $
# $Date: 2018-03-01 11:15:51 +0800 (Thu, 01 Mar 2018) $
# $Revision: 10799 $

from emencia.django.newsletter.models import Newsletter, Contact

from django.db import models
from django.utils.translation import ugettext_lazy as _

class Header(models.Model):

    title = models.CharField(
        _('title'), max_length=255, blank=True, null=True
    )
    content = models.TextField(
        _('Header content'), blank=True, null=True,
        help_text=_('Custom your header content.'))

    def __unicode__(self):
        return _('Header %s') % str(self.id)

    class Meta:
        verbose_name = _('Header')
        verbose_name_plural = _('Headers')

class Footer(models.Model):

    title = models.CharField(
        _('title'), max_length=255, blank=True, null=True
    )
    content = models.TextField(
        _('Footer content'), blank=True, null=True,
        help_text=_('Custom your footer content.'))

    def __unicode__(self):
        return _('Footer %s') % str(self.id)

    class Meta:
        verbose_name = _('Footer')
        verbose_name_plural = _('Footers')

class ErrorMessage(models.Model):

    message =  models.CharField(max_length=2048, blank=True, null=True)

    newsletter = models.ForeignKey(Newsletter, verbose_name=_('newsletter'))

    contact = models.ForeignKey(Contact, verbose_name=_('contact'))

# Newsletter track links patch, originally stored in Theophrastus/Patch.py
from emencia.django.newsletter.utils import newsletter
from Theophrastus.Utility import trackLinks

newsletter.track_links = trackLinks
